# Implements the nowcast calendar
# All models
calendar_inf_v3 <- function(Data, spl){
  
  t_eval <- floor(spl*nrow(Data$Y))
  nowcast_seq <- c(1,7,14,21,28) # Chosen days of nowcast
  ndays <- length(nowcast_seq)
  
  res <- matrix(NA, nrow = ndays, ncol = ncol(Data$Y))
  res_PMIDAS_HET <- matrix(NA, nrow = ndays, ncol = ncol(Data$Y))
  res_AR <- matrix(NA, nrow = ndays, ncol = ncol(Data$Y))
  
  for (ni in seq(nowcast_seq)) {
    nowcast_day <- nowcast_seq[ni]
    st <- Sys.time()
    cat(" Nowcast day", nowcast_day, "\n")
    Y <- Data$Y
    X1 <- Data$X1
    
    er <- matrix(NA, nrow = t_eval, ncol = ncol(Y))
    er_PMIDAS_HET <- matrix(NA, nrow = t_eval, ncol = ncol(Y))
    er_AR <- matrix(NA, nrow = t_eval, ncol = ncol(Y))
    
    for (j in 1:t_eval) {
      inpt_data <- list(Y = Y, X1 = X1)
      
      
      timevar <- (index(inpt_data$Y))
      end.pt <- timevar[(length(timevar) - j)] #low freq end pt
      
      t1 =  lubridate::ceiling_date(as.POSIXct(end.pt),"month") - 1
      
      inpt_data <- lapply(inpt_data, window, end = t1)
      
      
      # Get predictions
      pred <- pooled_cce(Data = inpt_data, nowcast_day)
      pred_PMIDAS_HET <- CCE(Data = inpt_data,nowcast_day)
      pred_AR <- AR(Data = inpt_data,nowcast_day)
      
      # Get errors
      act <- inpt_data$Y[nrow(inpt_data$Y),]
      er[j,] <- pred - t(coredata(act))
      er_PMIDAS_HET[j,] <- pred_PMIDAS_HET - coredata(act)
      er_AR[j,] <- pred_AR - coredata(act)
      
    }
    # RMSFE
    e_f <- apply(er, 2, function(x) sqrt(mean(x*x)))
    e_f_PMIDAS_HET <- apply(er_PMIDAS_HET, 2, function(x) sqrt(mean(x*x)))
    e_f_AR <- apply(er_AR, 2, function(x) sqrt(mean(x*x)))
    
    res[ni,] <- e_f
    res_PMIDAS_HET[ni,] <- e_f_PMIDAS_HET
    res_AR[ni,] <- e_f_AR
  }
  colnames(res) <- colnames(Y)
  colnames(res_PMIDAS_HET) <- colnames(Y)
  colnames(res_AR) <- colnames(Y)
  
  list(PMIDAS_Pooled = res, 
       PMIDAS_Heterogenous = res_PMIDAS_HET, 
       AR = res_AR
  )
}

