rm(list = ls())
graphics.off()
library(xts)
library(tsbox)
library(tidyverse)
library(lubridate)
library(gridExtra)
library(ggpubr)
library(knitr)
library(kableExtra)

# Load Functions
source(file = "Inflation nowcasting/Codes/Functions/pooled_cce.R")
source(file = "Inflation nowcasting/Codes/Functions/calendar_inf_pooled.R")
source(file = "Inflation nowcasting/Codes/Functions/CCE.R")
source(file = "Inflation nowcasting/Codes/Functions/AR.R")
source(file = "Inflation nowcasting/Codes/Functions/nearestdate.R")
source(file = "Inflation nowcasting/Codes/Functions/quantilefun.R")

# Load Data

INFL <- readRDS(file = "Inflation nowcasting/Data/INFLDATA.RDS")
spl = 0.3
run_results = 1 # set to 0 if do not want to regenerate results
if (run_results == 1) {
  # Main estimation
  # Takes a while to run
  Res <- lapply(INFL, `calendar_inf_v3`, spl = spl)
  Res <- lapply(Res, function(x) lapply(x, function(y) y*100))
  saveRDS(object = Res, file = "Inflation nowcasting/Results/INFLRES.RDS")
}
#############Tables 6-7 #####################
Res <- readRDS(file = "Inflation nowcasting/Results/INFLRES.RDS")
tabs <- lapply(Res, quantilefun)

t6 = kable(tabs$yoy, digits = 4, caption = "Quantiles of RMSFE(y-o-y)", format = "latex", booktabs = T) %>% 
  row_spec(0,bold = T) %>% 
  column_spec(1,bold = T) %>% 
  add_header_above(header = c(" " = 1,"Pooled" = 3, "Not Pooled" = 3, "TS AR" = 3), bold = T) %>% 
  add_header_above(header = c(" " = 1,"PMIDAS" = 6, "Benchmark" = 3), bold = T) %>% 
  footnote(alphabet = c(paste("Out of sample split = ", spl*100, "%"))) 
print(t6)


t7 = kable(tabs$mom, digits = 4, caption = "Quantiles of RMSFE(y-o-y)", format = "latex", booktabs = T) %>% 
  row_spec(0,bold = T) %>% 
  column_spec(1,bold = T) %>% 
  add_header_above(header = c(" " = 1,"Pooled" = 3, "Not Pooled" = 3, "TS AR" = 3), bold = T) %>% 
  add_header_above(header = c(" " = 1,"PMIDAS" = 6, "Benchmark" = 3), bold = T) %>% 
  footnote(alphabet = c(paste("Out of sample split = ", spl*100, "%"))) 
print(t7)
##############################################################
########Figures 6 -7 ###########
theme_ed <- theme(
  legend.position = "bottom",
  panel.background = element_rect(fill = NA),
  panel.border = element_rect(fill = NA, color = "grey75"),
  axis.ticks = element_line(color = "grey85"),
  panel.grid.major = element_line(color = "grey95", size = 0.2),
  panel.grid.minor = element_line(color = "grey95", size = 0.2),
  legend.key = element_blank(),
  text = element_text(size = 10)) 

Resmeans <- lapply(Res, function(x) sapply(x, rowMeans))
res_means_long <- lapply(Resmeans, function(x) pivot_longer(cbind.data.frame(H = c(1,7,15,21,28),x), -H, names_to = "Mdl", values_to = "RMSE"))

res_means_long <- lapply(res_means_long, function(x)  mutate(x, Type = ifelse(Mdl == "PMIDAS_Pooled", "Pooled", "Not Pooled"), Model = ifelse(Mdl %in% c("PMIDAS_Pooled", "PMIDAS_Heterogenous"), "PMIDAS", "TS AR")))

res_means_long <- lapply(res_means_long, function(x) dplyr::mutate(x, combo = paste(Model, Type, sep = " ")))
res_means_long <- lapply(res_means_long, function(x) dplyr::mutate(x, combo = replace(combo, combo == "TS AR Not Pooled", "TS AR")))




res_plots_final <- lapply(res_means_long, 
                          function(x) ggplot(x, aes(x = H, y = RMSE, col = combo, linetype = combo)) +
                            geom_line(size = .5) +
                            scale_x_continuous(name = "Days", breaks = c(1,7,14,21,28)) +
                            xlab("Days") +
                            theme_ed +
                            theme(legend.position = "bottom",legend.box = "vertical", legend.margin = margin()) +
                            scale_linetype_manual(name = "", values = c("solid", "dotted", "solid"), guide = F) +
                            scale_color_manual(name = "Model Type", values = c("blue", "blue", "black")) +
                            guides(colour = guide_legend(override.aes = list(linetype = c("solid", "dotted", "solid")))))

print(res_plots_final$yoy) + ggtitle("Fig 6")
print(res_plots_final$mom) + ggtitle("Fig 7")

path <- paste0("C:/Users/",Sys.getenv("USERNAME"),"/Dropbox/JAE Revision/Revision 2/Revised Charts")

ggsave(filename = "Inflation nowcasting/Results/Fig 6.pdf", height = 2.5, width = 5, res_plots_final$wow)

ggsave(filename = "Inflation nowcasting/Results/Fig 7.pdf", height = 2.5, width = 5, res_plots_final$yoy)


ggsave(filename = "C:/Users/Shaoni/Dropbox/JAE Revision/Revision 2/INFL_YOY_30.pdf", height = 2.5, width = 5, res_plots_final$wow)

ggsave(filename = "C:/Users/Shaoni/Dropbox/JAE Revision/Revision 2/INFL_MOM_30.pdf", height = 2.5, width = 5, res_plots_final$yoy)
